package com.nto.presentation.screens.profileScreen

import androidx.compose.foundation.Image
import androidx.compose.foundation.background
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.shape.CircleShape
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.automirrored.filled.ExitToApp
import androidx.compose.material3.Icon
import androidx.compose.material3.IconButton
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.res.stringResource
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.hilt.navigation.compose.hiltViewModel
import androidx.navigation.NavController
import androidx.navigation.compose.rememberNavController
import com.nto.presentation.R
import com.nto.presentation.composable.DecoratedButton
import com.nto.presentation.theme.NTOTheme
import com.nto.presentation.theme.TextGray

@Composable
fun ProfileScreen(
    navController: NavController,
    modifier: Modifier = Modifier,
    viewModel: ProfileViewModel = hiltViewModel<ProfileViewModel>(),
) {
    Column(
        modifier = modifier.background(NTOTheme.colors.primaryBackground)
    ) {
        Column(
            modifier = Modifier
                .fillMaxSize()
                .padding(start = 20.dp, end = 20.dp)
        ) {
            Spacer(modifier = Modifier.height(10.dp))
            Column(modifier = Modifier.weight(1f)) {
                Row(
                    modifier = Modifier.fillMaxWidth(),
                    horizontalArrangement = Arrangement.SpaceBetween,
                    verticalAlignment = Alignment.CenterVertically
                ) {
                    Text(
                        stringResource(R.string.title_profile),
                        style = NTOTheme.typography.titleLarge,
                        fontSize = 36.sp,
                        fontWeight = FontWeight.Bold
                    )
                    IconButton(modifier = Modifier
                        .size(40.dp)
                        .clip(CircleShape)
                        .background(NTOTheme.colors.buttonDisabled), onClick = {

                    }) {
                        Icon(
                            imageVector = Icons.AutoMirrored.Filled.ExitToApp,
                            modifier = Modifier.size(30.dp),
                            contentDescription = null
                        )
                    }
                }
                Spacer(modifier = Modifier.height(50.dp))
                Row(modifier = Modifier.fillMaxWidth()) {
                    Image(
                        painter = painterResource(R.drawable.logo_placeholder_user),
                        modifier = Modifier
                            .size(100.dp)
                            .clip(
                                CircleShape
                            ),
                        contentDescription = null
                    )
                    Spacer(modifier = Modifier.width(15.dp))
                    Column(
                        modifier = Modifier
                            .fillMaxWidth()
                            .clip(RoundedCornerShape(10.dp))
                            .background(NTOTheme.colors.inputFieldBackground)
                            .padding(10.dp)
                    ) {
                        Text(
                            "Левченко",
                            style = NTOTheme.typography.displaySmall,
                            fontWeight = FontWeight.Bold
                        )
                        Text(
                            "Егор",
                            style = NTOTheme.typography.displaySmall,
                            fontWeight = FontWeight.Bold
                        )
                        Text(
                            "Ростиславович",
                            style = NTOTheme.typography.displaySmall,
                            fontWeight = FontWeight.Bold
                        )
                        Spacer(modifier = Modifier.height(10.dp))
                        Text(
                            "Senior UI/UX Designer",
                            style = NTOTheme.typography.placeholder,
                            color = TextGray
                        )
                    }
                }
                Spacer(modifier = Modifier.height(20.dp))
                Row(
                    modifier = Modifier
                        .fillMaxWidth()
                        .height(35.dp)
                        .clip(RoundedCornerShape(10.dp))
                        .background(NTOTheme.colors.inputFieldBackground)
                        .padding(start = 15.dp, end = 15.dp),
                    verticalAlignment = Alignment.CenterVertically,
                    horizontalArrangement = Arrangement.SpaceBetween
                ) {
                    Text(
                        "Последний вход:", style = NTOTheme.typography.placeholder, fontSize = 12.sp
                    )
                    Text(
                        "24 января 20:01", style = NTOTheme.typography.placeholder, fontSize = 12.sp
                    )
                }
            }
            DecoratedButton(
                "Сканировать код",
                false,
                modifier = Modifier
                    .padding(10.dp)
                    .fillMaxWidth()
                    .height(50.dp)
            ) {

            }
        }
    }
}

@Preview
@Composable
private fun ProfileScreenPreview() {
    NTOTheme {
        ProfileScreen(rememberNavController(), Modifier.fillMaxSize())
    }
}